# cereggii

[![supports free-threading](https://github.com/dpdani/free-threading-badges/raw/main/supported.svg)](https://py-free-threading.github.io/)

Thread synchronization utilities for Python

```shell
pip install cereggii
```

*This library is beta quality: expect things to change.*

This package provides atomic versions of common data structures:

- `AtomicDict`
- `AtomicInt64`
- `AtomicRef`
- …and more to come

[Visit the docs for more information.](https://dpdani.github.io/cereggii)


## Cereus greggii

<img src="https://raw.githubusercontent.com/dpdani/cereggii/refs/heads/main/.github/cereggii.jpg" align="right">

The *Peniocereus Greggii* (also known as *Cereus Greggii*) is a flower native to
Arizona, New Mexico, Texas, and some parts of northern Mexico.

This flower blooms just one summer night every year and in any given area, all
these flowers bloom in synchrony.

[Wikipedia](https://en.wikipedia.org/wiki/Peniocereus_greggii)

_Image credits: Patrick Alexander, Peniocereus greggii var. greggii, south of
Cooke's Range, Luna County, New Mexico, 10 May 2018, CC0.
[source](https://www.flickr.com/photos/aspidoscelis/42926986382)_
